@@ -33,7 +33,7 @@ from draftutils.messages import _wrn
 
 if FreeCAD.GuiUp:
     import FreeCADGui
-    from PySide import QtCore, QtGui, QtSvg
+    from PySide import QtCore, QtGui, QtSvgWidgets
     from draftutils.translate import translate
     from PySide.QtCore import QT_TRANSLATE_NOOP
     import draftguitools.gui_trackers as DraftTrackers
@@ -424,7 +424,7 @@ class _CommandWindow:
         self.pic.hide()
 
         # SVG display
-        self.im = QtSvg.QSvgWidget(":/ui/ParametersWindowFixed.svg")
+        self.im = QtSvgWidgets.QSvgWidget(":/ui/ParametersWindowFixed.svg")
         self.im.setMaximumWidth(200)
         self.im.setMinimumHeight(120)
         grid.addWidget(self.im,4,0,1,2)
@@ -818,6 +818,8 @@ class _Window(ArchComponent.Component):
                             pass
                         elif omode == 10: # -sliding
                             pass
+                exv = FreeCAD.Vector()
+                zov = FreeCAD.Vector()
                 V = 0
                 thk = obj.WindowParts[(i*5)+3]
                 if "+V" in thk:
@@ -841,12 +843,19 @@ class _Window(ArchComponent.Component):
                     if zof:
                         zov = DraftVecUtils.scaleTo(norm,zof)
                         shape.translate(zov)
-                        for symb in ssymbols:
-                            symb.translate(zov)
-                        for symb in vsymbols:
-                            symb.translate(zov)
-                        if rotdata and hinge and omode:
-                            rotdata[0] = rotdata[0].add(zov)
+                if hinge and omode and 0 < omode < 9:
+                    if DraftVecUtils.angle(chord, norm, enorm) < 0:
+                        if omode%2 == 0:
+                            zov = zov.add(exv)
+                    else:
+                        if omode%2 == 1:
+                            zov = zov.add(exv)
+                    for symb in ssymbols:
+                        symb.translate(zov)
+                    for symb in vsymbols:
+                        symb.translate(zov)
+                    if rotdata:
+                        rotdata[0] = rotdata[0].add(zov)
                 if obj.WindowParts[(i*5)+1] == "Louvre":
                     if hasattr(obj,"LouvreWidth"):
                         if obj.LouvreWidth and obj.LouvreSpacing:
@@ -975,9 +984,9 @@ class _Window(ArchComponent.Component):
                     if not obj.Subvolume.Shape.isNull():
                         sh = obj.Subvolume.Shape.copy()
                         pl = FreeCAD.Placement(sh.Placement)
-                        pl = pl.multiply(obj.Placement)
+                        pl = obj.Placement.multiply(pl)
                         if plac:
-                            pl = pl.multiply(plac)
+                            pl = plac.multiply(pl)
                         sh.Placement = pl
                         return sh
 
@@ -1487,7 +1496,7 @@ class _ArchWindowTaskPanel:
 
     def getStandardButtons(self):
 
-        return int(QtGui.QDialogButtonBox.Close)
+        return QtGui.QDialogButtonBox.Close
 
     def check(self,wid,col):
 
